<div class="login-text">

    <h1>Sigmund is an AI research assistant</h1>
    
    <p>Designed to answer questions about OpenSesame</p>
    <p>Helps with data analysis and literature search</p>
    <p>Conversations are encrypted and will not be used to train AI</p>

</div>

<a id="sign-in-button" class="link-button" onclick="signin()">
    <i class="fas fa-sign-in-alt"></i> Sign in with CogSci forum<br>
    <small>Use your account from forum.cogsci.nl</small>
</a>

<a id="sign-in-button" class="link-button" href="/google_login">
    <i class="fab fa-google"></i> Sign in with Google<br>
    <small>Use your Google account</small>
</a>

<hr>

<small>

Read [what Sigmund can do](/about) and [our terms of service](/terms)

Sigmund requires a subscription (€9 /month). You can subscribe after signing in. A variety of international payment methods are available. Subscribing is easy and secure.

If you need a custom subscription, such as an invoiced subscription for multiple individuals or a longer period, contact [professional@cogsci.nl](mailto:professional@cogsci.nl).

</small>
